/*
 * hobbs.lex
 *
 * George Ferguson, ferguson@cs.rochester.edu, 19 Aug 2002
 * Time-stamp: <Mon Mar 10 13:47:31 EST 2003 ferguson>
 */

// Import Symbol type
import java_cup.runtime.Symbol;

%%

// Turn on Java CUP compatibility
%cup
%eofval{
  return new Symbol(sym.EOF);
%eofval}
%char
%line

%{
    // Methods for accessing lexer variables from parser
    public int getYychar() {
	return yychar;
    }
    public int getYyline() {
	return yyline;
    }
%}

%state AX

%%

<YYINITIAL> <axiom[\040\t]+id=\"[^\"]+\"> {
    //System.err.println("lex: starting axiom: " + yytext());
    yybegin(AX);
    int start = yytext().indexOf("id=\"") + 4;
    int end = yytext().indexOf("\">");
    String id = yytext().substring(start, end);
    return new Symbol(sym.BEGIN_AXIOM, id);
}
<YYINITIAL> .|\n {
    //System.err.println("lex: ignoring \"" + yytext() + "\"");
}
<AX> </axiom> {
    //System.err.println("lex: end of axiom");
    yybegin(YYINITIAL);
}

<AX> [\040\t\n]+		{ }

<AX> "("		{ return new Symbol(sym.OPEN_PAREN); }
<AX> ")"		{ return new Symbol(sym.CLOSE_PAREN); }
<AX> "["		{ return new Symbol(sym.OPEN_PAREN); }
<AX> "]"		{ return new Symbol(sym.CLOSE_PAREN); }
<AX> "-->"		{ return new Symbol(sym.RIGHT_ARROW); }
<AX> "<--"		{ return new Symbol(sym.LEFT_ARROW); }
<AX> "<-->"		{ return new Symbol(sym.DOUBLE_ARROW); }
<AX> "&"		{ return new Symbol(sym.AMPERSAND); }
<AX> "v"		{ return new Symbol(sym.V); }
<AX> "~"		{ return new Symbol(sym.TILDE); }
<AX> "A"		{ return new Symbol(sym.A); }
<AX> "E"		{ return new Symbol(sym.E); }
<AX> "E!"		{ return new Symbol(sym.E_BANG); }
<AX> ","		{ return new Symbol(sym.COMMA); }
<AX> "="		{ return new Symbol(sym.EQUALS); }
<AX> "=/="		{ return new Symbol(sym.NOT_EQUALS); }
<AX> "<"		{ return new Symbol(sym.LESS_THAN); }
<AX> "<="		{ return new Symbol(sym.LESS_THAN_OR_EQUALS); }
<AX> ">"		{ return new Symbol(sym.GREATER_THAN); }
<AX> ">="		{ return new Symbol(sym.GREATER_THAN_OR_EQUALS); }
<AX> "+"		{ return new Symbol(sym.PLUS); }
<AX> "-"		{ return new Symbol(sym.MINUS); }
<AX> "*"		{ return new Symbol(sym.TIMES); }
<AX> "/"		{ return new Symbol(sym.DIVIDE); }
<AX> "U"		{ return new Symbol(sym.U); }
<AX> "{"		{ return new Symbol(sym.LEFT_BRACE); }
<AX> "}"		{ return new Symbol(sym.RIGHT_BRACE); }

<AX> [0-9][0-9]*	{ return new Symbol(sym.NUMBER, yytext()); }

<AX> [a-zA-Z\*][a-zA-Z0-9_\-\*]*	{ return new Symbol(sym.ID, yytext()); }

<AX> .  { System.err.println("Illegal character: " + yytext()); }

.  { System.err.println("Illegal character outside AX: " + yytext()); }

